# Changelog

## [0.2.1] - 2020-07-09

- Try to rebuild wheels

## [0.2.0] - 2020-07-01

- New methods for creating a bounding sphere. #10

## [0.1.2] - 2020-06-01

- Try again to publish to PyPI directly

## [0.1.1] - 2020-06-01

- Try building wheels on CI with `cibuildwheel`

## [0.1.0] - 2020-05-30

- Initial release
